@@ -1,6 +1,6 @@
 package WWW::Google::Places::DetailResult;
 
-$WWW::Google::Places::DetailResult::VERSION   = '0.30';
+$WWW::Google::Places::DetailResult::VERSION   = '0.31';
 $WWW::Google::Places::DetailResult::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,18 +9,22 @@ WWW::Google::Places::DetailResult - Placeholder for detail Search Result for WWW
 
 =head1 VERSION
 
-Version 0.30
+Version 0.31
 
 =cut
 
 use 5.006;
 use Data::Dumper;
+use WWW::Google::Places::Photo;
 use WWW::Google::Places::Review;
+use WWW::Google::Places::Address;
 use WWW::Google::Places::Geometry;
 
 use Moo;
 use namespace::clean;
 
+use overload q{""} => 'as_string', fallback => 1;
+
 has 'place_id'               => (is => 'ro', required => 1            );
 has 'website'                => (is => 'ro', default  => sub { 'N/A' });
 has 'formatted_phone_number' => (is => 'ro', default  => sub { 'N/A' });
@@ -46,23 +50,40 @@ has 'address_components'     => (is => 'ro');
 sub BUILDARGS {
     my ($class, $args) = @_;
 
-    my $objects = [];
+    my $reviews = [];
     if (exists $args->{reviews}) {
-        my $reviews = $args->{reviews};
-        foreach (@$reviews) {
-            push @$objects, WWW::Google::Places::Review->new($_);
+        foreach (@{$args->{reviews}}) {
+            push @$reviews, WWW::Google::Places::Review->new($_);
         }
     }
     else {
-        push @$objects, WWW::Google::Places::Review->new;
+        push @$reviews, WWW::Google::Places::Review->new;
     }
 
-    $args->{reviews} = $objects;
+    $args->{reviews} = $reviews;
 
     if (exists $args->{geometry}) {
         $args->{geometry} = WWW::Google::Places::Geometry->new($args->{geometry});
     }
 
+    if (exists $args->{photos}) {
+        my $photos = [];
+        foreach (@{$args->{photos}}) {
+            push @$photos, WWW::Google::Places::Photo->new($_);
+        }
+
+        $args->{photos} = $photos;
+    }
+
+    if (exists $args->{address_components}) {
+        my $address_components = [];
+        foreach (@{$args->{address_components}}) {
+            push @$address_components, WWW::Google::Places::Address->new($_);
+        }
+
+        $args->{address_components} = $address_components;
+    }
+
     return $args;
 }
 
@@ -132,6 +153,8 @@ Returns place address.
 
 =head2 address_components()
 
+Returns ref to a list of objects of type L<WWW::Google::Places::Address>.
+
 =head2 opening_hours()
 
 Returns place opening hours.
@@ -142,6 +165,70 @@ Returns place internation number.
 
 =head2 photos()
 
+Returns ref to a list of objects of type L<WWW::Google::Places::Photo>.
+
+=cut
+
+sub as_string {
+    my ($self) = @_;
+
+    my $detail_result = '';
+    $detail_result .= sprintf("Place ID          : %s\n", $self->place_id);
+    $detail_result .= sprintf("Name              : %s\n", $self->name);
+    $detail_result .= sprintf("Website           : %s\n", $self->website);
+    $detail_result .= sprintf("URL               : %s\n", $self->url);
+    $detail_result .= sprintf("Phone Number      : %s\n", $self->formatted_phone_number);
+    $detail_result .= sprintf("Opening Hours     : %s\n", $self->opening_hours);
+    $detail_result .= sprintf("Internation Number: %s\n", $self->internation_number);
+    $detail_result .= sprintf("UTF Offset        : %s\n", $self->utf_offset);
+    $detail_result .= sprintf("Rating            : %s\n", $self->rating);
+    $detail_result .= sprintf("User Ratings      : %s\n", $self->user_ratings_total);
+    $detail_result .= sprintf("Vicinity          : %s\n", $self->vicinity);
+    $detail_result .= sprintf("Address           : %s\n", $self->adr_address);
+    $detail_result .= sprintf("Reference         : %s\n", $self->reference);
+    $detail_result .= sprintf("Geometry          : %s\n", $self->geometry);
+    $detail_result .= sprintf("Scope             : %s\n", $self->scope);
+    $detail_result .= sprintf("Icon              : %s\n", $self->icon);
+    $detail_result .= sprintf("Types             : %s\n", join(", ", @{$self->types}));
+    $detail_result .= sprintf("Address           : %s\n", $self->formatted_address);
+
+    if (@{$self->address_components}) {
+        $detail_result .= sprintf("Address Components:\n");
+        foreach (@{$self->address_components}) {
+            $detail_result .= sprintf("\tShort Name: %s\n", $_->short_name);
+            $detail_result .= sprintf("\tLong Name : %s\n", $_->long_name);
+            $detail_result .= sprintf("\tTypes     : %s\n", join(", ", @{$_->types}));
+            $detail_result .= sprintf("\t-----------\n");
+        }
+    }
+
+    if (@{$self->reviews}) {
+        $detail_result .= sprintf("Reviews           :\n");
+        foreach (@{$self->reviews})  {
+            $detail_result .= sprintf("\tAuthor Name: %s\n", $_->author_name);
+            $detail_result .= sprintf("\tAuthor URL : %s\n", $_->author_url);
+            $detail_result .= sprintf("\tLanguage   : %s\n", $_->language);
+            $detail_result .= sprintf("\tRating     : %s\n", $_->rating);
+            $detail_result .= sprintf("\tText       : %s\n", $_->text);
+            $detail_result .= sprintf("\tTime       : %s\n", $_->time);
+            $detail_result .= sprintf("\tAspects    : %s\n", $_->aspects||'N/A');
+            $detail_result .= sprintf("\t-----------\n");
+        }
+    }
+    if (@{$self->photos}) {
+        $detail_result .= sprintf("Photos            : \n");
+        foreach (@{$self->photos}) {
+            $detail_result .= sprintf("\tWidth             :%s\n", $_->width);
+            $detail_result .= sprintf("\tHeight            :%s\n", $_->height);
+            $detail_result .= sprintf("\tReference         :%s\n", $_->photo_reference);
+            $detail_result .= sprintf("\tHTML Attributions :%s\n", join("<BR", @{$_->html_attributions}));
+            $detail_result .= sprintf("\t-------------------\n");
+        }
+    }
+
+    return $detail_result;
+}
+
 =head1 AUTHOR
 
 Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
